@@ -115,9 +115,8 @@
 /*	With locally submitted mail, append the string ".$mydomain" to
 /*	addresses that have no ".domain" information.
 /* .IP "\fBrecipient_delimiter (empty)\fR"
-/*	The set of characters that can separate a user name from its
-/*	extension (example: user+foo), or a .forward file name from its
-/*	extension (example: .forward+foo).
+/*	The set of characters that can separate an email address
+/*	localpart, user name, or a .forward file name from its extension.
 /* .IP "\fBswap_bangpath (yes)\fR"
 /*	Enable the rewriting of "site!user" into "user@site".
 /* .PP
@@ -522,17 +521,16 @@ static void pre_accept(char *unused_name, char **unused_argv)
 
 #endif
 
-/* post_accept - anounce our protocol name */
+/* post_accept - announce our protocol name */
 
 static void post_accept(VSTREAM *stream, char *unused_name, char **unused_argv,
 			        HTABLE *unused_attr)
 {
+
     /*
-     * Announce the protocol. Allow lazy clients to receive this together
-     * with the server's response to the client request, but also allow
-     * greedy clients to detect a service mismatch early.
+     * Announce the protocol.
      */
-    attr_print(stream, ATTR_FLAG_MORE,
+    attr_print(stream, ATTR_FLAG_NONE,
 	       SEND_ATTR_STR(MAIL_ATTR_PROTO, MAIL_ATTR_PROTO_TRIVIAL),
 	       ATTR_TYPE_END);
     (void) vstream_fflush(stream);
